# fairy_script/block.py

ass_script_info = [
    "Title",
    "ScriptType",
    "WrapStyle",
    "ScaledBorderAndShadow",
    "YCbCr Matrix",
    "Original Script",
    "Original Translation",
    "Original Editing",
    "Original Timing",
    "Synch Point",
    "Script Updated By",
    "Update Details",
    "PlayResX",
    "PlayDepth",
    "Collsions",
    "Normal",
    "Reverse",
    "Timer",
]


ass_v4_style = [
    "Name",
    "FontName",
    "Fontsize",
    "PrimaryColour",
    "SecondaryColour",
    "OutlineColour",
    "BackColour",
    "Bold",
    "Italic",
    "Underline",
    "StrikeOut",
    "ScaleX",
    "ScaleY",
    "Spacing",
    "Angle",
    "BorderStyle",
    "Outline",
    "Shadow",
    "Alignment",
    "MarginL",
    "MarginR",
    "MarginV",
    "Encoding",
]
